systemtools.LilyPondFormatManager
=================================

.. abjad-lineage:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager

.. autoclass:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.bundle_format_contributions
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_attribute
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_context_setting_in_with_block
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_context_setting_inline
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_value
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.make_lilypond_override_string
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.make_lilypond_revert_string
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.report_component_format_contributions
      ~abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.report_spanner_format_contributions

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.bundle_format_contributions
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_attribute
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_context_setting_in_with_block
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_context_setting_inline
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.format_lilypond_value
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.make_lilypond_override_string
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.make_lilypond_revert_string
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.report_component_format_contributions
   :noindex:

.. automethod:: abjad.tools.systemtools.LilyPondFormatManager.LilyPondFormatManager.report_spanner_format_contributions
   :noindex:
